Documentation
¶
Overview ¶
Package logger provides a minimal structured-logger interface and a default stdlib-based implementation for the poya SDK.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Logger ¶
type Logger interface {
Debug(msg string, keysAndValues ...any)
Info(msg string, keysAndValues ...any)
Warn(msg string, keysAndValues ...any)
Error(msg string, keysAndValues ...any)
}
Logger is the interface used by the poya SDK for all log output. It follows the idiomatic Go pattern (like zap's sugared logger or klog).
func NewWithHandler ¶
NewWithHandler returns a Logger backed by the given slog.Handler. Useful for tests or custom formatting.
Click to show internal directories.
Click to hide internal directories.